# Sample Card

2019-05-07, @bhrutledge, `green`, `Sample Label`

Sample description

## Checklist

- [x] Completed item
- [ ] Incomplete item

## Attachments

- [Example link](https://example.com)

## Comments

### bhrutledge on 2019-05-06

Sample comment
